From fb4fa2107dab487880c8147d64cb78509cb780fa Mon Sep 17 00:00:00 2001
From: "Bryn M. Reeves" <bmr@redhat.com>
Date: Fri, 20 Jun 2014 14:30:29 +0100
Subject: [PATCH 2/4] [printing] fix cups log file size limiting

Signed-off-by: Bryn M. Reeves <bmr@redhat.com>
---
 sos/plugins/printing.py | 13 ++++++++++---
 1 file changed, 10 insertions(+), 3 deletions(-)

diff --git a/sos/plugins/printing.py b/sos/plugins/printing.py
index 06cf21a..bf96187 100644
--- a/sos/plugins/printing.py
+++ b/sos/plugins/printing.py
@@ -17,12 +17,19 @@ import sos.plugintools
 class printing(sos.plugintools.PluginBase):
     """printing related information (cups)
     """
-    optionList = [("cups", "max size (MiB) to collect per cups log file",
-                   "", 50)]
+    optionList = [("logsize", "max size (MiB) to collect per log file", "", 5),
+                  ("all_logs", "collect all cups log files", "", False)]
 
     def setup(self):
+        # all_logs takes precedence over logsize
+        if not self.getOption("all_logs"):
+            limit = self.getOption("logsize")
+            self.addCopySpecLimit("/var/log/cups/access_log", sizelimit=limit)
+            self.addCopySpecLimit("/var/log/cups/error_log", sizelimit=limit)
+            self.addCopySpecLimit("/var/log/cups/page_log", sizelimit=limit)
+        else:
+            self.addCopySpec("/var/log/cups")
         self.addCopySpec("/etc/cups/*.conf")
-        self.addCopySpecLimit("/var/log/cups", sizelimit=self.isOptionEnabled("cupslogsize"))
         self.addCopySpec("/etc/cups/lpoptions")
         self.addCopySpec("/etc/cups/ppd/*.ppd")
         self.collectExtOutput("/usr/bin/lpstat -t")
-- 
1.9.3

